==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/es.js <==
/**
 * Spanish
 */

$.Editable.LANGS['es'] = {
  translation: {
    "Bold": "Negrita",
    "Italic": "It\u00e1lica",
    "Underline": "Subrayado",
    "Strikethrough": "Tachado",
    "Font Size": "Tama\u00f1o de fuente",
    "Color": "Color",
    "Background Color": "Color de fondo",
    "Text Color": "Color del texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "P\u00e1rrafo",
    "Code": "C\u00f3digo",
    "Quote": "Bloque de cita",
    "Heading 1": "Encabezado 1",
    "Heading 2": "Encabezado 2",
    "Heading 3": "Encabezado 3",
    "Heading 4": "Encabezado 4",
    "Heading 5": "Encabezado 5",
    "Heading 6": "Encabezado 6",
    "Alignment": "Alineaci\u00f3n",
    "Align Left": "Alinear a la izquierda",
    "Align Center": "Alinear al centro",
    "Align Right": "Alinear a la derecha",
    "Justify": "Justificar",
    "Numbered List": "Lista numerada",
    "Bulleted List": "Lista de vi\u00f1etas",
    "Indent Less": "Disminuir sangr\u00eda",
    "Indent More": "Incrementar sangr\u00eda",
    "Select All": "Seleccionar todo",
    "Insert Link": "Insertar enlace",
    "Insert Image": "Insertar imagen",
    "Insert Video": "Insertar video",
    "Undo": "Deshacer",
    "Redo": "Rehacer",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Izquierda",
    "Float None": "Ninguno",
    "Float Right": "Derecha",
    "Replace Image": "Reemplazar la imagen",
    "Remove Image": "Quitar la imagen",
    "Title": "T\u00edtulo",
    "Insert image": "Insertar imagen",
    "Drop image": "Soltar la imagen",
    "or click": "o haga clic en",
    "Enter URL": "Escribir la URL",
    "Please wait!": "Por favor, espere!",
    "Are you sure? Image will be deleted.": "\u00bfEst\u00e1 seguro? Imagen ser\u00e1 borrada.",
    "UNLINK": "Quitar enlace",
    "Open in new tab": "Abrir en una nueva pesta\u00F1a",
    "Type something": "Escriba algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Administrar im\u00e1genes",
    "Delete": "Borrar",
    "Font Family": "Familia de fuentes",
    "Insert Horizontal Line": "Insertar l\u00ednea horizontal"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.5.tar.gz: django-froala-editor-0.8.5/froala_editor/static/froala_editor/js/langs/es.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Spanish
 */

$.Editable.LANGS['es'] = {
  translation: {
    "Bold": "Negrita",
    "Italic": "It\u00e1lica",
    "Underline": "Subrayado",
    "Strikethrough": "Tachado",
    "Font Size": "Tama\u00f1o de fuente",
    "Color": "Color",
    "Background Color": "Color de fondo",
    "Text Color": "Color del texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "P\u00e1rrafo",
    "Code": "C\u00f3digo",
    "Quote": "Bloque de cita",
    "Heading 1": "Encabezado 1",
    "Heading 2": "Encabezado 2",
    "Heading 3": "Encabezado 3",
    "Heading 4": "Encabezado 4",
    "Heading 5": "Encabezado 5",
    "Heading 6": "Encabezado 6",
    "Alignment": "Alineaci\u00f3n",
    "Align Left": "Alinear a la izquierda",
    "Align Center": "Alinear al centro",
    "Align Right": "Alinear a la derecha",
    "Justify": "Justificar",
    "Numbered List": "Lista numerada",
    "Bulleted List": "Lista de vi\u00f1etas",
    "Indent Less": "Disminuir sangr\u00eda",
    "Indent More": "Incrementar sangr\u00eda",
    "Select All": "Seleccionar todo",
    "Insert Link": "Insertar enlace",
    "Insert Image": "Insertar imagen",
    "Insert Video": "Insertar video",
    "Undo": "Deshacer",
    "Redo": "Rehacer",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Izquierda",
    "Float None": "Ninguno",
    "Float Right": "Derecha",
    "Replace Image": "Reemplazar la imagen",
    "Remove Image": "Quitar la imagen",
    "Title": "T\u00edtulo",
    "Insert image": "Insertar imagen",
    "Drop image": "Soltar la imagen",
    "or click": "o haga clic en",
    "Enter URL": "Escribir la URL",
    "Please wait!": "Por favor, espere!",
    "Are you sure? Image will be deleted.": "\u00bfEst\u00e1 seguro? Imagen ser\u00e1 borrada.",
    "UNLINK": "Quitar enlace",
    "Open in new tab": "Abrir en una nueva pesta\u00F1a",
    "Type something": "Escriba algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Administrar im\u00e1genes",
    "Delete": "Borrar",
    "Font Family": "Familia de fuentes",
    "Insert Horizontal Line": "Insertar l\u00ednea horizontal",
    "Table": "Tabla",
    "Insert table": "Insertar tabla",
    "Cell": "Celda",
    "Row": "Fila",
    "Column": "Columna",
    "Delete table": "Eliminar tabla",
    "Insert cell before": "Insertat celda antes",
    "Insert cell after": "Insertat celda despu\u00e9s",
    "Delete cell": "Eliminar celda",
    "Merge cells": "Combinar celdas",
    "Horizontal split": "Divisi\u00f3n horizontal",
    "Vertical split": "Divisi\u00f3n vertical",
    "Insert row above": "Insertar fila antes",
    "Insert row below": "Insertar fila despu\u00e9s",
    "Delete row": "Eliminar Fila",
    "Insert column before": "Insertar columna antes",
    "Insert column after": "Insertar columna despu\u00e9s",
    "Delete column": "Eliminar columna"
  },
  direction: "ltr"
};
